@@ -36,3 +36,23 @@ pub fn cwd() -> Option<String> {
         )),
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use std::env;
+
+    #[test]
+    fn test_cwd() {
+        let path = format!("{}", env::current_dir().unwrap().display());
+
+        env::set_var("IAY_SHORTEN_CWD", "0");
+        env::set_var("IAY_EXPAND_TILDE", "1");
+        env::set_var("IAY_CWD_HOME_COLOR", "bright red");
+
+        assert_eq!(
+            cwd(),
+            Some(colors::colored_string(&path, "bright red", "bold"))
+        )
+    }
+}
