@@ -7,33 +7,29 @@ mod prompt_char;
 mod vcs;
 mod venv;
 
-use std::env;
+use clap::Parser;
 
-use clap::{App, Arg};
 use iay::colors;
 
+#[derive(Parser)]
+#[clap(author, version, about, long_about = None)]
+struct Args {
+    /// Use minimal variant
+    #[clap(short, long)]
+    minimal: bool,
+
+    /// Use ZSH formatting
+    #[clap(short, long)]
+    zsh: bool,
+}
+
 fn main() {
-    let matches = App::new("iay")
-        .version(env!("CARGO_PKG_VERSION"))
-        .author(env!("CARGO_PKG_AUTHORS"))
-        .about(env!("CARGO_PKG_DESCRIPTION"))
-        .arg(
-            Arg::with_name("minimal")
-                .short("m")
-                .long("minimal")
-                .help("use minimal variant"),
-        )
-        .arg(
-            Arg::with_name("zsh")
-                .short("z")
-                .long("zsh")
-                .help("Use ZSH formatting"),
-        )
-        .get_matches();
-    if matches.is_present("minimal") {
-        println!("{}", iay_prompt_minimal(matches.is_present("zsh")));
+    let cmd = Args::parse();
+
+    if cmd.minimal {
+        println!("{}", iay_prompt_minimal(cmd.zsh));
     } else {
-        println!("{}", iay_prompt(matches.is_present("zsh")));
+        println!("{}", iay_prompt(cmd.zsh));
     }
 }
 
@@ -43,14 +39,7 @@ fn iay_prompt(zsh: bool) -> String {
         None => colors::colored_string("[directory does not exist]", "red", ""),
     };
 
-    let vcs_component = match env::var("IAY_DISABLE_VCS")
-        .unwrap_or_else(|_| "0".into())
-        .as_ref()
-    {
-        "0" => vcs_tray(),
-        _ => "".into(),
-    };
-
+    let vcs_status = vcs::status();
     let venv = venv::get_name();
     let prompt_char = prompt_char::prompt_char(zsh);
 
@@ -58,7 +47,7 @@ fn iay_prompt(zsh: bool) -> String {
         format!(
             "%{{{cwd}{vcs}%}} %{{\n{venv}{pchar}%}} ",
             cwd = cwd,
-            vcs = vcs_component,
+            vcs = vcs_status,
             venv = venv,
             pchar = prompt_char
         )
@@ -66,7 +55,7 @@ fn iay_prompt(zsh: bool) -> String {
         format!(
             "{cwd}{vcs}\n{venv}{nix}{pchar} ",
             cwd = cwd,
-            vcs = vcs_component,
+            vcs = vcs_status,
             venv = venv,
             pchar = prompt_char,
             nix = venv::in_nix_shell()
@@ -80,13 +69,7 @@ fn iay_prompt_minimal(zsh: bool) -> String {
         None => colors::colored_string("[directory does not exist]", "red", " "),
     };
 
-    let vcs_component = match env::var("IAY_DISABLE_VCS")
-        .unwrap_or_else(|_| "0".into())
-        .as_ref()
-    {
-        "0" => vcs_tray(),
-        _ => "".into(),
-    };
+    let vcs_status = vcs::status();
 
     let venv = venv::get_name();
     let prompt_char = prompt_char::prompt_char(zsh);
@@ -95,7 +78,7 @@ fn iay_prompt_minimal(zsh: bool) -> String {
         let fmt = format!(
             "{cwd}{vcs}{venv}{pchar} ",
             cwd = cwd,
-            vcs = vcs_component,
+            vcs = vcs_status,
             venv = venv,
             pchar = prompt_char
         );
@@ -123,21 +106,9 @@ fn iay_prompt_minimal(zsh: bool) -> String {
         format!(
             "{cwd}{vcs}{venv}{pchar} ",
             cwd = cwd,
-            vcs = vcs_component,
+            vcs = vcs_status,
             venv = venv,
             pchar = prompt_char
         )
     }
 }
-
-fn vcs_tray() -> String {
-    let vcs_tuple = vcs::vcs_status();
-    let mut vcs_component = String::new();
-    if let Some((branch, status)) = vcs_tuple {
-        vcs_component = format!(" {}{} ", branch, status);
-    } else {
-        vcs_component.push(' ');
-    }
-
-    vcs_component
-}
